**********************
* OVERVIEW
*   This script generates tables, figures, and in-text numbers for the paper:
*   "From Extreme to Mainstream: The Erosion of Social Norms"
*   Leonardo Bursztyn, Georgy Egorov, Stefano Fiorin
*   All raw data are stored in /data
*   All processed data are outputted in /processed
*   All tables are outputted to /results/tables
*   All figures are outputted to /results/figures
*   All in-text numbers are outputted to /results/numbers
*   All log files are outputted to /logs	
* 
* SOFTWARE REQUIREMENTS
*   Analyses run on Ubuntu using Stata version 15
*
* TO PERFORM A CLEAN RUN, DELETE THE FOLLOWING TWO FOLDERS:
*   /processed
*   /results
**********************

* User must define a global macro in order to run the analysis:
* (1) "ExtremeToMainstream_Replication" points to the project folder
* global ExtremeToMainstream_Replication "home/stefano/ExtremeToMainstream_Replication"

************
* Code begins
************

* Confirm that the globals for the project root directory has been defined
assert !missing("$ExtremeToMainstream_Replication")

* Initialize log and record system parameters
clear 
set more off
cap mkdir "$ExtremeToMainstream_Replication/logs"
cap log close
local datetime : di %tcCCYY.NN.DD!_HH.MM.SS `=clock("$S_DATE $S_TIME", "DMYhms")'
local logfile "$ExtremeToMainstream_Replication/logs/log_`datetime'.txt"
log using "`logfile'", text

di "Begin date and time: $S_DATE $S_TIME"
di "Stata version: `c(stata_version)'"
di "Updated as of: `c(born_date)'"
di "Variant:       `=cond( c(MP),"MP",cond(c(SE),"SE",c(flavor)) )'"
di "Processors:    `c(processors)'"
di "OS:            `c(os)' `c(osdtl)'"
di "Machine type:  `c(machine_type)'"

* All required Stata packages are available in the /libraries/stata folder
adopath ++ "$ExtremeToMainstream_Replication/scripts/libraries/stata"

* Stata programs are stored in /programs
adopath ++ "$ExtremeToMainstream_Replication/scripts/programs"

* Stata version control
version 15

* Create directories for output files
cap mkdir "$ExtremeToMainstream_Replication/processed"
cap mkdir "$ExtremeToMainstream_Replication/processed/intermediate"
cap mkdir "$ExtremeToMainstream_Replication/results"
cap mkdir "$ExtremeToMainstream_Replication/results/figures"
cap mkdir "$ExtremeToMainstream_Replication/results/tables"
cap mkdir "$ExtremeToMainstream_Replication/results/numbers"

* Run project analysis
do "$ExtremeToMainstream_Replication/scripts/1_process_raw_data.do"
do "$ExtremeToMainstream_Replication/scripts/2_clean_data.do"
do "$ExtremeToMainstream_Replication/scripts/3_figures.do"
texdoc do "$ExtremeToMainstream_Replication/scripts/4_tables.do"
do "$ExtremeToMainstream_Replication/scripts/5_numbers.do"

* End log
di "End date and time: $S_DATE $S_TIME"
log close

** EOF
