************
* SCRIPT: 2_clean_data.do
* PURPOSE: processes the datasets in preparation for analysis
************

************
* Code begins
************



********************
*** Experiment 1 ***
********************

use "$ExtremeToMainstream_Replication/processed/intermediate/exp1.dta", clear

* Rename Variables

rename q1 consent
rename q2 county_confirm
rename q3_a facts_known_clinton
rename q3_b facts_known_trump
rename q4_a donation_public
rename q4_b donation_private
rename q5_a sob_culture
rename q5_b sob_immigration
rename q6 gender
rename q7 year_of_birth
rename q8 ethnicity
rename q9 education
rename q10 income
rename q11 household_size
rename q12 marital_status

* Label Variables

label var consent "Please indicate, in the box below, that you are at least 18 years old, have read and understand this consent form, and you agree to participate in this online research study."
label var county_confirm "Please confirm that you live in one of the following counties: Allegheny, Armstrong, Beaver, Butler, Fayette, Washington, Westmoreland."
label var facts_known_clinton "Which of these facts did you know before reading them here?"
label var facts_known_trump "Which of these facts did you know before reading them here?"
label var donation_public "Would you like us to donate $1 to FAIR on your behalf?"
label var donation_private "Would you like us to donate $1 to FAIR on your behalf?"
label var sob_culture "What % of Pittsburgh voters you believe would agree with the quote `For European American society and culture to persist requires a European-American majority, and a clear one at that'?"
label var sob_immigration "What % of Pittsburgh voters you believe would agree with the quote `Both legal and illegal immigration should be drastically reduced because immigrants undermine American culture and do not respect American values'?"
label var gender "What is your gender?"
label var year_of_birth "What is your year of birth?"
label var ethnicity "How would you describe your ethnicity/race? Please, check all that apply."
label var education "What is the highest level of school you have completed or the highest degree you have received?"
label var income "What is your household annual income? Please indicate the answer that includes your entire household income in 2015 before taxes."
label var household_size "How many people are in your household?"
label var marital_status "What is your marital status?"

* Define Variables

g donate = (donation_public == "Yes, please donate $1 to FAIR on my behalf." | donation_private == "Yes, please donate $1 to FAIR on my behalf.")

g female = (gender == "Female") if missing(gender) == 0

g age = 2018 - year_of_birth if missing(year_of_birth) == 0

g white = regexm(ethnicity,"White or European American*") == 1 if missing(ethnicity) == 0

g years_edu = 10 if education == "Less than high school degree"
replace years_edu = 12 if education == "High school graduate (high school diploma or equivalent including GED)"
replace years_edu = 13 if education == "Some college but no degree"
replace years_edu = 14 if education == "Associate degree in college (2-year)"
replace years_edu = 16 if education == "Bachelor's degree in college (4-year)"
replace years_edu = 18 if education == "Master's degree"
replace years_edu = 21 if education == "Professional degree (JD, MD)"
replace years_edu = 21 if education == "Doctoral degree"

g income_000s = 10 if income == "Less than $10,000"
replace income_000s = 15 if income == "$10,000 to $19,999"
replace income_000s = 25 if income == "$20,000 to $29,999"
replace income_000s = 35 if income == "$30,000 to $39,999"
replace income_000s = 45 if income == "$40,000 to $49,999"
replace income_000s = 55 if income == "$50,000 to $59,999"
replace income_000s = 65 if income == "$60,000 to $69,999"
replace income_000s = 75 if income == "$70,000 to $79,999"
replace income_000s = 85 if income == "$80,000 to $89,999"
replace income_000s = 95 if income == "$90,000 to $99,999"
replace income_000s = 125 if income == "$100,000 to $149,999"
replace income_000s = 150 if income == "$150,000 or more"

g married = (marital_status == "Married") if missing(marital_status) == 0

g missing_demographics = missing(gender) == 1

g clinton_private = (t_trump_clinton == "Clinton Won" & t_public_private == "Private")
g clinton_public = (t_trump_clinton == "Clinton Won" & t_public_private == "Public") 
g trump_private = (t_trump_clinton == "Trump Won" & t_public_private == "Private") 
g trump_public = (t_trump_clinton == "Trump Won" & t_public_private == "Public")

g trump = t_trump_clinton == "Trump Won"
g public = t_public_private == "Public"

g treatment = t_trump_clinton + " " + t_public_private

* Save Clean Dataset

compress
save "$ExtremeToMainstream_Replication/processed/exp1_clean.dta", replace



********************
*** Experiment 2 ***
********************

use "$ExtremeToMainstream_Replication/processed/intermediate/exp2.dta", clear

* Rename Variables

rename q1 consent
rename q2 state
rename q3 gender
rename q4 year_of_birth
rename q5 ethnicity
rename q6 education
rename q7 income
rename q8 vote
rename q9 vote_text
rename q10 marital_status
rename q11_a sob_culture
rename q11_b sob_immigration
rename q12 donation_amount

* Label Variables

label var consent "Please indicate, in the box below, that you are at least 18 years old, have read and understand this consent form, and you agree to participate in this online research study."
label var state "What is your state of legal residence?"
label var gender "What is your gender?"
label var year_of_birth "What is your year of birth?"
label var ethnicity "How would you describe your ethnicity/race? Please, check all that apply."
label var education "What is the highest level of school you have completed or the highest degree you have received?"
label var income "What is your household annual income? Please indicate the answer that includes your entire household income in 2015 before taxes."
label var vote "Whom did you vote for in the last election?"
label var vote_text "Whom did you vote for in the last election? Other:"
label var marital_status "What is your marital status?"
label var sob_culture "What % of voters in the other participant's area you think would agree with the quote `For European American society and culture to persist requires a European-American majority, and a clear one at that'?"
label var sob_immigration "What % of voters in the other participant's area you think would agree with the quote `Both legal and illegal immigration should be drastically reduced because immigrants undermine American culture and do not respect American values'?"
label var donation_amount "How much would you like to give to the other participant?"

* Define Variables

g no_donation = (donation_amount == 0)

g female = (gender == "Female") if missing(gender) == 0

g age = 2018 - year_of_birth if missing(year_of_birth) == 0

g white = regexm(ethnicity,"White or European American*") == 1 if missing(ethnicity) == 0

g years_edu = 10 if education == "Less than high school degree"
replace years_edu = 12 if education == "High school graduate (high school diploma or equivalent including GED)"
replace years_edu = 13 if education == "Some college but no degree"
replace years_edu = 14 if education == "Associate degree in college (2-year)"
replace years_edu = 16 if education == "Bachelor's degree in college (4-year)"
replace years_edu = 18 if education == "Master's degree"
replace years_edu = 21 if education == "Professional degree (JD, MD)"
replace years_edu = 21 if education == "Doctoral degree"

g income_000s = 10 if income == "Less than $10,000"
replace income_000s = 15 if income == "$10,000 to $19,999"
replace income_000s = 25 if income == "$20,000 to $29,999"
replace income_000s = 35 if income == "$30,000 to $39,999"
replace income_000s = 45 if income == "$40,000 to $49,999"
replace income_000s = 55 if income == "$50,000 to $59,999"
replace income_000s = 65 if income == "$60,000 to $69,999"
replace income_000s = 75 if income == "$70,000 to $79,999"
replace income_000s = 85 if income == "$80,000 to $89,999"
replace income_000s = 95 if income == "$90,000 to $99,999"
replace income_000s = 125 if income == "$100,000 to $149,999"
replace income_000s = 150 if income == "$150,000 or more"

g married = (marital_status == "Married") if missing(marital_status) == 0

g clinton_private = (t_trump_clinton == "Clinton Won" & t_public_private == "Private")
g clinton_public = (t_trump_clinton == "Clinton Won" & t_public_private == "Public") 
g trump_private = (t_trump_clinton == "Trump Won" & t_public_private == "Private") 
g trump_public = (t_trump_clinton == "Trump Won" & t_public_private == "Public")

g trump = t_trump_clinton == "Trump Won"
g public = t_public_private == "Public"

g treatment = t_trump_clinton + " " + t_public_private

* Save Clean Dataset

compress
save "$ExtremeToMainstream_Replication/processed/exp2_clean.dta", replace



******************************
*** Appendix Experiment 1B ***
******************************

*** Wave 1 Pilot

use "$ExtremeToMainstream_Replication/processed/intermediate/app_exp1b_wave1_pilot.dta", clear

* Rename Variables

rename q1 state
rename q2 gender
rename q3 year_of_birth
rename q4 marital_status
rename q5 ethnicity
rename q6 education
rename q7 income
rename q8 prob_trump_win_info
rename q9 sob
rename q10_a donation_anti
rename q10_b donation_pro

tempfile wave1_pilot
save `wave1_pilot', replace


*** Wave 1

use "$ExtremeToMainstream_Replication/processed/intermediate/app_exp1b_wave1.dta", clear

* Rename Variables

rename q1 state
rename q2 gender
rename q3 year_of_birth
rename q4 marital_status
rename q5 ethnicity
rename q6 education
rename q7 income
rename q8 prob_trump_win_info
rename q9 sob
rename q10_a donation_anti
rename q10_b donation_pro
rename q11 prob_trump_win_control

tempfile wave1
save `wave1', replace


*** Wave 2

use "$ExtremeToMainstream_Replication/processed/intermediate/app_exp1b_wave2.dta", clear

* Rename Variables

rename q1 state
rename q2 gender
rename q3 year_of_birth
rename q4 marital_status
rename q5 ethnicity
rename q6 education
rename q7 income
rename q8 sob
rename q9_a donation_anti
rename q9_b donation_pro

tempfile wave2
save `wave2', replace


* Append datasets

use `wave1_pilot', clear
g wave = "Wave 1 pilot"
append using `wave1'
replace wave = "Wave 1" if wave == ""
append using `wave2'
replace wave = "Wave 2" if wave == ""
replace t_info_control = "Control" if wave == "Wave 2"

* Label Variables

label var state "What is your state of legal residence?"
label var gender "What is your gender?"
label var year_of_birth "What is your year of birth?"
label var marital_status "What is your marital status?"
label var ethnicity "How would you describe your ethnicity/race? Please, check all that apply."
label var education "What is the highest level of school you have completed or the highest degree you have received?"
label var income "What is your household annual income? Please indicate the answer that includes your entire household income in 2015 before taxes."
label var prob_trump_win_info "What do you think is the probability of Donald Trump winning the presidential election in [state]?"
label var prob_trump_win_control "What do you think is the probability of Donald Trump winning the presidential election in [state]?"
label var sob "What share of people in [state] do you think agree with the statement `For European American society and culture to persist requires a European-American majority, and a clear one at that'?"
label var donation_anti "Would you like to have us donate $1 on your behalf to the Federation for American Immigration Reform?"
label var donation_pro "Would you like to have us donate $1 on your behalf to the National Immigration Forum?"


* Define Variables

g donate = (donation_anti == "Yes") if missing(donation_anti) == 0

g female = (gender == "Female") if missing(gender) == 0

g age = 2016 - year_of_birth if missing(year_of_birth) == 0

g white = regexm(ethnicity,"White or European American*") == 1 if missing(ethnicity) == 0

g years_edu = 10 if education == "Less than high school degree"
replace years_edu = 12 if education == "High school graduate (high school diploma or equivalent including GED)"
replace years_edu = 13 if education == "Some college but no degree"
replace years_edu = 14 if education == "Associate degree in college (2-year)"
replace years_edu = 16 if education == "Bachelor's degree in college (4-year)"
replace years_edu = 18 if education == "Master's degree"
replace years_edu = 21 if education == "Professional degree (JD, MD)"
replace years_edu = 21 if education == "Doctoral degree"

g income_000s = 10 if income == "Less than $10,000"
replace income_000s = 15 if income == "$10,000 to $19,999"
replace income_000s = 25 if income == "$20,000 to $29,999"
replace income_000s = 35 if income == "$30,000 to $39,999"
replace income_000s = 45 if income == "$40,000 to $49,999"
replace income_000s = 55 if income == "$50,000 to $59,999"
replace income_000s = 65 if income == "$60,000 to $69,999"
replace income_000s = 75 if income == "$70,000 to $79,999"
replace income_000s = 85 if income == "$80,000 to $89,999"
replace income_000s = 95 if income == "$90,000 to $99,999"
replace income_000s = 125 if income == "$100,000 to $149,999"
replace income_000s = 150 if income == "$150,000 or more"

g married = (marital_status == "Married") if missing(marital_status) == 0

duplicates tag matchid, gen(dup)
g wave2_surveyed_before = dup == 1 if wave == "Wave 2"
drop dup

g info_private = (t_info_control == "Information" & t_public_private == "Private" & wave != "Wave 2")
g info_public = (t_info_control == "Information" & t_public_private == "Public" & wave != "Wave 2") 
g control_private = (t_info_control == "Control" & t_public_private == "Private" & wave != "Wave 2") 
g control_public = (t_info_control == "Control" & t_public_private == "Public" & wave != "Wave 2")
g wave2_private = (t_public_private == "Private" & wave == "Wave 2") 
g wave2_public = (t_public_private == "Public" & wave == "Wave 2")

g group = t_info_control + " " + t_public_private
replace group = group + " " + wave if wave == "Wave 2"

* Save Clean Dataset

compress
save "$ExtremeToMainstream_Replication/processed/app_exp1b_clean.dta", replace



******************************
*** Appendix Experiment 2B ***
******************************

*** Wave 1

use "$ExtremeToMainstream_Replication/processed/intermediate/app_exp2b_wave1.dta", clear

tempfile wave1
save `wave1', replace


*** Wave 2

use "$ExtremeToMainstream_Replication/processed/intermediate/app_exp2b_wave2.dta", clear

tempfile wave2
save `wave2', replace


* Append datasets

use `wave1', clear
g wave = "Wave 1"
append using `wave2'
replace wave = "Wave 2" if wave == ""

* Rename Variables

rename q1 state
rename q2 gender
rename q3 year_of_birth
rename q4 marital_status
rename q5 ethnicity
rename q6 education
rename q7 income
rename q8 minarets
rename q9 donation_amount
rename q10 sob
rename q11 legal_illegal

* Label Variables

label var state "What is your state of legal residence?"
label var gender "What is your gender?"
label var year_of_birth "What is your year of birth?"
label var marital_status "What is your marital status?"
label var ethnicity "How would you describe your ethnicity/race? Please, check all that apply."
label var education "What is the highest level of school you have completed or the highest degree you have received?"
label var income "What is your household annual income? Please indicate the answer that includes your entire household income in 2015 before taxes."
label var minarets "Would you support the introduction of a law prohibiting the building of minarets in California?"
label var donation_amount "How much would you like to give to the other person?"
label var sob "Out of 100 respondents from Switzerland, how many do you believe would support prohibiting the building of minarets?"
label var legal_illegal "Do you think building minarets is legal or illegal in Switzerland?"

* Define Variables

g no_donation = (donation_amount == 0) if donation_amount != .

g sob_50 = sob > 50 if missing(sob) == 0

g believe_legal = legal_illegal == "Legal" if missing(legal_illegal) == 0

g female = (gender == "Female") if missing(gender) == 0

g age = 2017 - year_of_birth if missing(year_of_birth) == 0

g white = regexm(ethnicity,"White or European American*") == 1 if missing(ethnicity) == 0

g years_edu = 10 if education == "Less than high school degree"
replace years_edu = 12 if education == "High school graduate (high school diploma or equivalent including GED)"
replace years_edu = 13 if education == "Some college but no degree"
replace years_edu = 14 if education == "Associate degree in college (2-year)"
replace years_edu = 16 if education == "Bachelor's degree in college (4-year)"
replace years_edu = 18 if education == "Master's degree"
replace years_edu = 21 if education == "Professional degree (JD, MD)"
replace years_edu = 21 if education == "Doctoral degree"

g income_000s = 10 if income == "Less than $10,000"
replace income_000s = 15 if income == "$10,000 to $19,999"
replace income_000s = 25 if income == "$20,000 to $29,999"
replace income_000s = 35 if income == "$30,000 to $39,999"
replace income_000s = 45 if income == "$40,000 to $49,999"
replace income_000s = 55 if income == "$50,000 to $59,999"
replace income_000s = 65 if income == "$60,000 to $69,999"
replace income_000s = 75 if income == "$70,000 to $79,999"
replace income_000s = 85 if income == "$80,000 to $89,999"
replace income_000s = 95 if income == "$90,000 to $99,999"
replace income_000s = 125 if income == "$100,000 to $149,999"
replace income_000s = 150 if income == "$150,000 or more"

g married = (marital_status == "Married") if missing(marital_status) == 0

g control = (treatment == "Control")
g support = (treatment == "Anti-Minarets Public Support" & wave == "Wave 1")
g support_anonymous = (treatment == "Anti-Minarets Public Support" & wave == "Wave 2")
g anti_minarets = (treatment == "Anti-Minarets" & wave == "Wave 1")
g anti_minarets_anonymous = (treatment == "Anti-Minarets" & wave == "Wave 2")
g referendum = (treatment == "Anti-Minarets Referendum" & wave == "Wave 1")
g referendum_anonymous = (treatment == "Anti-Minarets Referendum" & wave == "Wave 2")

g anonymity = "Anonymous" if wave == "Wave 2"

g group = treatment if wave == "Wave 1"
replace group = treatment + " " + anonymity if wave == "Wave 2"
replace group = treatment if treatment == "Control"
replace group = "" if treatment == ""

* Save Clean Dataset

compress
save "$ExtremeToMainstream_Replication/processed/app_exp2b_clean.dta", replace



*****************************
*** Appendix Experiment 3 ***
*****************************

use "$ExtremeToMainstream_Replication/processed/intermediate/app_exp3.dta", clear

* Rename Variables

rename q1 state
rename q2 gender
rename q3 year_of_birth
rename q4 marital_status
rename q5 ethnicity
rename q6 education
rename q7 income
rename q8 sob
rename q9_a donation_anti
rename q9_b donation_pro

* Label Variables

label var state "What is your state of legal residence?"
label var gender "What is your gender?"
label var year_of_birth "What is your year of birth?"
label var marital_status "What is your marital status?"
label var ethnicity "How would you describe your ethnicity/race? Please, check all that apply."
label var education "What is the highest level of school you have completed or the highest degree you have received?"
label var income "What is your household annual income? Please indicate the answer that includes your entire household income in 2015 before taxes."
label var sob "Out of 100 people, how many do you think would say in an anonymous survey that they think Muslims should be prohibited from holding public office?"
label var donation_anti "Would you like to have us donate $1 on your behalf to ACT for America?"
label var donation_pro " Would you like to have us donate $1 on your behalf to the National Immigration Forum?"

* Define Variables

g donate = (donation_anti == "Yes") if missing(donation_anti) == 0

g female = (gender == "Female") if missing(gender) == 0

g age = 2017 - year_of_birth if missing(year_of_birth) == 0

g white = regexm(ethnicity,"White or European American*") == 1 if missing(ethnicity) == 0

g years_edu = 10 if education == "Less than high school degree"
replace years_edu = 12 if education == "High school graduate (high school diploma or equivalent including GED)"
replace years_edu = 13 if education == "Some college but no degree"
replace years_edu = 14 if education == "Associate degree in college (2-year)"
replace years_edu = 16 if education == "Bachelor's degree in college (4-year)"
replace years_edu = 18 if education == "Master's degree"
replace years_edu = 21 if education == "Professional degree (JD, MD)"
replace years_edu = 21 if education == "Doctoral degree"

g income_000s = 10 if income == "Less than $10,000"
replace income_000s = 15 if income == "$10,000 to $19,999"
replace income_000s = 25 if income == "$20,000 to $29,999"
replace income_000s = 35 if income == "$30,000 to $39,999"
replace income_000s = 45 if income == "$40,000 to $49,999"
replace income_000s = 55 if income == "$50,000 to $59,999"
replace income_000s = 65 if income == "$60,000 to $69,999"
replace income_000s = 75 if income == "$70,000 to $79,999"
replace income_000s = 85 if income == "$80,000 to $89,999"
replace income_000s = 95 if income == "$90,000 to $99,999"
replace income_000s = 125 if income == "$100,000 to $149,999"
replace income_000s = 150 if income == "$150,000 or more"

g married = (marital_status == "Married") if missing(marital_status) == 0

g support_private = (t_support_const_control == "Public Support Information" & t_public_private == "Private")
g support_public = (t_support_const_control == "Public Support Information" & t_public_private == "Public")
g const_private = (t_support_const_control == "Unconstitutionality Information" & t_public_private == "Private")
g const_public = (t_support_const_control == "Unconstitutionality Information" & t_public_private == "Public")
g control_private = (t_support_const_control == "Control" & t_public_private == "Private") 
g control_public = (t_support_const_control == "Control" & t_public_private == "Public")

g support = support_private + support_public
g const = const_private + const_public
g control = control_private + control_public

g treatment = t_support_const_control + " " + t_public_private

* Save Clean Dataset

compress
save "$ExtremeToMainstream_Replication/processed/app_exp3_clean.dta", replace


*** Auxiliary Survey

use "$ExtremeToMainstream_Replication/processed/intermediate/app_exp3_auxiliarysurvey.dta", clear

* Rename Variables

rename q1 state
rename q2 gender
rename q3 year_of_birth
rename q4 marital_status
rename q5 ethnicity
rename q6 education
rename q7 income
rename q8 public_office

* Label Variables

label var state "What is your state of legal residence?"
label var gender "What is your gender?"
label var year_of_birth "What is your year of birth?"
label var marital_status "What is your marital status?"
label var ethnicity "How would you describe your ethnicity/race? Please, check all that apply."
label var education "What is the highest level of school you have completed or the highest degree you have received?"
label var income "What is your household annual income? Please indicate the answer that includes your entire household income in 2015 before taxes."
label var public_office "Do you think Muslims should be prohibited from holding public office?"

* Save Clean Dataset

compress
save "$ExtremeToMainstream_Replication/processed/app_exp3_auxiliarysurvey_clean.dta", replace

** EOF
