************
* SCRIPT: 4_tables.do
* PURPOSE: creates the tex tables for the paper
************

************
* Code begins
************

* Preamble set numbers of replications for permutation tests
local n_reps = 1000

* Define controls
local controls female age married years_edu income_000s white


********************
*** Experiment 1 ***
********************

use "$ExtremeToMainstream_Replication/processed/exp1_clean.dta", clear




***********
* Table 1 *
***********

local public_b = "Public"
local public_se = ""
local public_p = ""
local trump_b = "Trump Won"
local trump_se = ""
local trump_p = ""
local trump_public_b = "Public*Trump Won"
local trump_public_se = ""
local trump_public_p = ""
local constant = "Clinton Won & \multicolumn{2}{c}"
local obs = "N"
local r2 = `"\$"' + "\mathnormal{R}^2" + "\\$"
generate treatment_ritest = 0
replace treatment_ritest = 1 if public == 1
replace treatment_ritest = 2 if trump == 1
replace treatment_ritest = 3 if trump_public == 1

reg donate public trump trump_public, r
local constant = "`constant'" + "{" + string(round(_b[_cons],.001),"%9.3f") + "}"
forvalues column = 1(1)2 {
if `column' == 1 reg donate public trump trump_public, r
if `column' == 2 reg donate public trump trump_public `controls', r
local obs = "`obs'" +  " & " + string(e(N))
local r2 = "`r2'" + " & " + string(round(e(r2),.001),"%9.3f")
foreach d in public trump trump_public {
local `d'_b = "``d'_b'" +  " & " + string(round(_b[`d'],.001),"%9.3f")
local `d'_se = "``d'_se'" + " & " + "(" + string(round(_se[`d'],.001),"%9.3f") + ")"
}
if `column' == 1 ritest treatment_ritest (_b[i1.treatment_ritest]) (_b[i2.treatment_ritest]) (_b[i3.treatment_ritest] - _b[i1.treatment_ritest] - _b[i2.treatment_ritest]), reps(`n_reps') seed(1): regress donate i.treatment_ritest
if `column' == 2 ritest treatment_ritest (_b[i1.treatment_ritest]) (_b[i2.treatment_ritest]) (_b[i3.treatment_ritest] - _b[i1.treatment_ritest] - _b[i2.treatment_ritest]), reps(`n_reps') seed(1): regress donate i.treatment_ritest `controls'
matrix p = r(p)
local i = 1
foreach d in public trump trump_public {
local val = p[1,`i']
if string(round(`val',.001),"%9.3f") != "0.000" local `d'_p = "``d'_p'" + " & " + "[" + string(round(`val',.001),"%9.3f") + "]"
if string(round(`val',.001),"%9.3f") == "0.000" local `d'_p = "``d'_p'" + " & " + "[" + "$<$0.001" + "]"
local ++i
}
}

texdoc init "$ExtremeToMainstream_Replication/results/tables/table1.tex", replace

/*tex
\begin{tabularx}{l*{2}{>{\centering\arraybackslash}X}}
\\
\hline
            Dependent&\multicolumn{2}{l}{Dummy: individual authorizes donation}\\
                        Variable&\multicolumn{2}{l}{to anti-immigration organization}\\
\hline
            &\multicolumn{1}{c}{(1)}&\multicolumn{1}{c}{(2)}\\
\hline
tex*/

local stata_locals public_b public_se public_p trump_b trump_se trump_p trump_public_b trump_public_se trump_public_p constant obs r2
foreach i of local stata_locals {
texdoc local `i' = "``i''" + "\\"
}

texdoc write `public_b'
texdoc write `public_se'
texdoc write `public_p'
texdoc write `trump_b'
texdoc write `trump_se'
texdoc write `trump_p'
texdoc write `trump_public_b'
texdoc write `trump_public_se'
texdoc write `trump_public_p'

/*tex
\\
Mean Donation Rate \\
tex*/
texdoc write `constant'
/*tex
Private Treatment\\
\hline
Controls & No & Yes\\
tex*/
texdoc write `obs'
texdoc write `r2'
/*tex
\hline
\end{tabularx}
tex*/

texdoc close



***********
* Table 2 *
***********

local trump_b = "Trump Won Treatment"
local trump_se = ""
local constant1 = "Clinton Won & \multicolumn{2}{c}"
local sob_culture_50_b = "Perceived Share of Voters & &"
local sob_culture_50_se = "Holding Xenophobic Views & &"
local constant2 = "Perceived Share of Voters & &"
local obs = "N"
generate sob_culture_50 = sob_culture - 50

* Panel A
forvalues column = 1(1)6 {
if `column' == 1 {
reg sob_culture trump, r
local constant1 = "`constant1'" + "{" + string(round(_b[_cons],.001),"%9.3f") + "}"
}
if `column' == 2 reg sob_culture trump `controls', r
if `column' == 3 {
reg sob_culture trump if public == 0, r
local constant1 = "`constant1'" + " & \multicolumn{2}{c}" + "{" + string(round(_b[_cons],.001),"%9.3f") + "}"
}
if `column' == 4 reg sob_culture trump `controls' if public == 0, r
if `column' == 5 {
reg sob_culture trump if public == 1, r
local constant1 = "`constant1'" + " & \multicolumn{2}{c}" + "{" + string(round(_b[_cons],.001),"%9.3f") + "}"
}
if `column' == 6 reg sob_culture trump `controls' if public == 1, r
local obs = "`obs'" +  " & " + string(e(N))
foreach d in trump {
local `d'_b = "``d'_b'" +  " & " + string(round(_b[`d'],.001),"%9.3f")
local `d'_se = "``d'_se'" + " & " + "(" + string(round(_se[`d'],.001),"%9.3f") + ")"
}
}

* Panel B
forvalues column = 3(1)6 {
if `column' == 3 {
ivregress gmm donate (sob_culture_50 = trump) if public == 0, r
local constant2 = "`constant2'" + " & \multicolumn{2}{c}" + "{" + string(round(_b[_cons],.001),"%9.3f") + "}"
}
if `column' == 4 ivregress gmm donate (sob_culture_50 = trump) `controls' if public == 0, r
if `column' == 5 {
ivregress gmm donate (sob_culture_50 = trump) if public == 1, r
local constant2 = "`constant2'" + " & \multicolumn{2}{c}" + "{" + string(round(_b[_cons],.001),"%9.3f") + "}"
}
if `column' == 6 ivregress gmm donate (sob_culture_50 = trump) `controls' if public == 1, r
foreach d in sob_culture_50 {
local `d'_b = "``d'_b'" +  " & " + string(round(_b[`d'],.001),"%9.3f")
local `d'_se = "``d'_se'" + " & " + "(" + string(round(_se[`d'],.001),"%9.3f") + ")"
}
}

texdoc init "$ExtremeToMainstream_Replication/results/tables/table2.tex", replace

/*tex
\begin{tabularx}{0.96\textwidth}{l*{6}{>{\centering\arraybackslash}X}}
\\
\hline
\multicolumn{7}{c}{\emph{Panel A: First Stage Regressions}}\\
\hline
            Dependent Variable &\multicolumn{6}{l}{Perceived Share of Voters Holding Xenophobic Views}\\
           
            &\multicolumn{1}{c}{(1)}&\multicolumn{1}{c}{(2)}&\multicolumn{1}{c}{(3)}&\multicolumn{1}{c}{(4)} & (5) & (6)\\
\hline
tex*/

local stata_locals trump_b trump_se constant1 sob_culture_50_b sob_culture_50_se constant2 obs
foreach i of local stata_locals {
texdoc local `i' = "``i''" + "\\"
}

texdoc write `trump_b'
texdoc write `trump_se'

/*tex
\\
Mean Perceived Share \\
tex*/
texdoc write `constant1'
/*tex
Treatment\\
\hline
\multicolumn{7}{c}{\emph{Panel B: Instrumental Variable Regressions}}\\
\hline
            Dependent&\multicolumn{6}{l}{Dummy: individual authorizes donation to anti-immigration  organization}\\
                                    &\multicolumn{1}{c}{(1)}&\multicolumn{1}{c}{(2)}&\multicolumn{1}{c}{(3)}&\multicolumn{1}{c}{(4)} & (5) & (6)\\
\hline
tex*/

texdoc write `sob_culture_50_b'
texdoc write `sob_culture_50_se'

/*tex
\\
Mean Donation Rate at a 50\%\\
tex*/
texdoc write `constant2'
/*tex
Holding Xenophobic Views\\
\hline
Sample & \multicolumn{2}{c}{Full Sample} & \multicolumn{2}{c}{Private Treatment} & \multicolumn{2}{c}{Public Treatment}\\
Controls & No & Yes & No & Yes & No & Yes\\
tex*/
texdoc write `obs'
/*tex
\hline
\end{tabularx}
tex*/

texdoc close




************
* Table B1 *
************

local female_avg = "Female"
local female_sd = ""
local age_avg = "Age"
local age_sd = ""
local married_avg = "Married"
local married_sd = ""
local years_edu_avg = "Years of Education"
local years_edu_sd = ""
local income_000s_avg = "Household Income"
local income_000s_sd = "\quad (000s)"
local white_avg = "White"
local white_sd = ""
local missing_demographics_avg = "No Demographics"
local missing_demographics_sd = ""
local obs = "N"

local i = 1
foreach v of var `controls' missing_demographics {
sum `v'
local `v'_avg = "``v'_avg'" + "&" + string(round(r(mean),.001),"%9.3f")
local `v'_sd = "``v'_sd'" + "&" + "[" + string(round(r(sd),.001),"%9.3f") + "]"
if `i' == 7 {
local obs = "`obs'" + "&" + string(r(N))
}
foreach w of var clinton_private clinton_public trump_private trump_public {
sum `v' if `w' == 1
if `i' == 7 {
local obs = "`obs'" + "&" + string(r(N))
}
reg `v' clinton_private clinton_public trump_private trump_public, r nocons
local `v'_avg = "``v'_avg'" + "&" + string(round(_b[`w'],.001),"%9.3f")
local `v'_sd = "``v'_sd'" + "&" + "(" + string(round(_se[`w'],.001),"%9.3f") + ")"
}
test _b[clinton_private] = _b[clinton_public] = _b[trump_private] = _b[trump_public]
local `v'_avg = "``v'_avg'" + "&" + string(round(r(p),.001),"%9.3f")
local ++i
}

texdoc init "$ExtremeToMainstream_Replication/results/tables/tableB1.tex", replace

/*tex
\begin{tabular}{l*{6}{c}}
\\
\hline
            &\multicolumn{1}{c}{Full Sample}&\multicolumn{1}{c}{Clinton Won}&\multicolumn{1}{c}{Clinton Won}&\multicolumn{1}{c}{Trump Won}&\multicolumn{1}{c}{Trump Won}&\multicolumn{1}{c}{p-\emph{value}}\\
			&&\multicolumn{1}{c}{Private}&\multicolumn{1}{c}{Public}&\multicolumn{1}{c}{Private}&\multicolumn{1}{c}{Public}&\\
                        

            &         (1)&        (2)&        (3)&         (4)&         (5) & (6)\\
\hline
tex*/

local stata_locals female_avg female_sd age_avg age_sd married_avg married_sd years_edu_avg years_edu_sd income_000s_avg income_000s_sd white_avg white_sd missing_demographics_avg missing_demographics_sd obs
foreach i of local stata_locals {
texdoc local `i' = "``i''" + "\\"
}

texdoc write `female_avg'
texdoc write `female_sd'
texdoc write `age_avg'
texdoc write `age_sd'
texdoc write `married_avg'
texdoc write `married_sd'
texdoc write `years_edu_avg'
texdoc write `years_edu_sd'
texdoc write `income_000s_avg'
texdoc write `income_000s_sd'
texdoc write `white_avg'
texdoc write `white_sd'
texdoc write `missing_demographics_avg'
texdoc write `missing_demographics_sd'
texdoc write \hline
texdoc write `obs'
/*tex
\hline
\end{tabular}
tex*/

texdoc close



************
* Table B2 *
************

local public_b = "Public"
local public_se = ""
local trump_b = "Trump Won"
local trump_se = ""
local trump_public_b = "Public*Trump Won"
local trump_public_se = ""
local constant = "Clinton Won"
local obs = "N"
local r2 = `"\$"' + "\mathnormal{R}^2" + "\\$"
centile age
g age_above_median = age > r(c_1) if missing(age) == 0
centile years_edu
g edu_above_median = years_edu > r(c_1) if missing(years_edu) == 0
centile income_000s
g income_above_median = income_000s > r(c_1) if missing(income_000s) == 0

foreach v of var white female age_above_median married edu_above_median income_above_median {
forvalues j = 0(1)1 {
reg donate public trump trump_public if `v' == `j', r
local constant = "`constant'" +  " & " + string(round(_b[_cons],.001),"%9.3f")
local obs = "`obs'" +  " & " + string(e(N))
local r2 = "`r2'" + " & " + string(round(e(r2),.001),"%9.3f")
foreach d in public trump trump_public {
local `d'_b = "``d'_b'" +  " & " + string(round(_b[`d'],.001),"%9.3f")
local `d'_se = "``d'_se'" + " & " + "(" + string(round(_se[`d'],.001),"%9.3f") + ")"
}
}
}

texdoc init "$ExtremeToMainstream_Replication/results/tables/tableB2.tex", replace

/*tex
\begin{tabular}{lcccccccccccc} \hline
 & \multicolumn{2}{c}{White} & \multicolumn{2}{c}{Female} & \multicolumn{2}{c}{Age} & \multicolumn{2}{c}{Married} & \multicolumn{2}{c}{Education} & \multicolumn{2}{c}{Income} \\ 
& No & Yes & No & Yes & Below & Above & No & Yes & Below & Above & Below & Above \\
& & & & & Median & Median & & & Median & Median & Median & Median\\
 & (1) & (2) & (3) & (4) & (5) & (6) & (7) & (8) & (9) & (10) & (11) & (12) \\
 \hline
 \\
tex*/

local stata_locals public_b public_se trump_b trump_se trump_public_b trump_public_se constant obs r2
foreach i of local stata_locals {
texdoc local `i' = "``i''" + "\\"
}

texdoc write `public_b'
texdoc write `public_se'
texdoc write `trump_b'
texdoc write `trump_se'
texdoc write `trump_public_b'
texdoc write `trump_public_se'

/*tex
\\
Mean Donation Rate \\
tex*/
texdoc write `constant'
/*tex
Private Treatment\\
\hline
tex*/
texdoc write `obs'
texdoc write `r2'
/*tex
\hline
\end{tabular}
tex*/

texdoc close





********************
*** Experiment 2 ***
********************

use "$ExtremeToMainstream_Replication/processed/exp2_clean.dta", clear



***********
* Table 3 *
***********

local trump_b = "Trump Won Treatment"
local trump_se = ""
local constant1 = "Clinton Won & \multicolumn{2}{c}"
local sob_culture_50_b = "Perceived Share of Voters & &"
local sob_culture_50_se = "Holding Xenophobic Views & &"
local constant2 = "Perceived Share of Voters & &"
local sob_culture_50c_b = "Perceived Share of Voters & &"
local sob_culture_50c_se = "Holding Xenophobic Views & &"
local constant3 = "Perceived Share of Voters & &"
local obs = "N"
generate sob_culture_50 = sob_culture - 50
generate sob_culture_50c = sob_culture - 50

* Panel A
forvalues column = 1(1)6 {
if `column' == 1 {
reg sob_culture trump, r
local constant1 = "`constant1'" + "{" + string(round(_b[_cons],.001),"%9.3f") + "}"
}
if `column' == 2 reg sob_culture trump `controls', r
if `column' == 3 {
reg sob_culture trump if public == 0, r
local constant1 = "`constant1'" + " & \multicolumn{2}{c}" + "{" + string(round(_b[_cons],.001),"%9.3f") + "}"
}
if `column' == 4 reg sob_culture trump `controls' if public == 0, r
if `column' == 5 {
reg sob_culture trump if public == 1, r
local constant1 = "`constant1'" + " & \multicolumn{2}{c}" + "{" + string(round(_b[_cons],.001),"%9.3f") + "}"
}
if `column' == 6 reg sob_culture trump `controls' if public == 1, r
local obs = "`obs'" +  " & " + string(e(N))
foreach d in trump {
local `d'_b = "``d'_b'" +  " & " + string(round(_b[`d'],.001),"%9.3f")
local `d'_se = "``d'_se'" + " & " + "(" + string(round(_se[`d'],.001),"%9.3f") + ")"
}
}

* Panel B
forvalues column = 3(1)6 {
if `column' == 3 {
ivregress gmm donation_amount (sob_culture_50 = trump) if public == 0, r
local constant2 = "`constant2'" + " & \multicolumn{2}{c}" + "{" + string(round(_b[_cons],.001),"%9.3f") + "}"
}
if `column' == 4 ivregress gmm donation_amount (sob_culture_50 = trump) `controls' if public == 0, r
if `column' == 5 {
ivregress gmm donation_amount (sob_culture_50 = trump) if public == 1, r
local constant2 = "`constant2'" + " & \multicolumn{2}{c}" + "{" + string(round(_b[_cons],.001),"%9.3f") + "}"
}
if `column' == 6 ivregress gmm donation_amount (sob_culture_50 = trump) `controls' if public == 1, r
foreach d in sob_culture_50 {
local `d'_b = "``d'_b'" +  " & " + string(round(_b[`d'],.001),"%9.3f")
local `d'_se = "``d'_se'" + " & " + "(" + string(round(_se[`d'],.001),"%9.3f") + ")"
}
}

forvalues column = 3(1)6 {
if `column' == 3 {
ivregress gmm no_donation (sob_culture_50c = trump) if public == 0, r
local constant3 = "`constant3'" + " & \multicolumn{2}{c}" + "{" + string(round(_b[_cons],.001),"%9.3f") + "}"
}
if `column' == 4 ivregress gmm no_donation (sob_culture_50c = trump) `controls' if public == 0, r
if `column' == 5 {
ivregress gmm no_donation (sob_culture_50c = trump) if public == 1, r
local constant3 = "`constant3'" + " & \multicolumn{2}{c}" + "{" + string(round(_b[_cons],.001),"%9.3f") + "}"
}
if `column' == 6 ivregress gmm no_donation (sob_culture_50c = trump) `controls' if public == 1, r
foreach d in sob_culture_50c {
local `d'_b = "``d'_b'" +  " & " + string(round(_b[`d'],.001),"%9.3f")
local `d'_se = "``d'_se'" + " & " + "(" + string(round(_se[`d'],.001),"%9.3f") + ")"
}
}

texdoc init "$ExtremeToMainstream_Replication/results/tables/table3.tex", replace

/*tex
\begin{tabularx}{0.96\textwidth}{l*{6}{>{\centering\arraybackslash}X}}
\\
\hline
\multicolumn{7}{c}{\emph{Panel A: First Stage Regressions}}\\
\hline
            Dependent Variable &\multicolumn{6}{l}{Perceived Share of Voters Holding Xenophobic Views}\\
           
            &\multicolumn{1}{c}{(1)}&\multicolumn{1}{c}{(2)}&\multicolumn{1}{c}{(3)}&\multicolumn{1}{c}{(4)} & (5) & (6)\\
\hline
tex*/

local stata_locals trump_b trump_se constant1 sob_culture_50_b sob_culture_50_se constant2 sob_culture_50c_b sob_culture_50c_se constant3 obs
foreach i of local stata_locals {
texdoc local `i' = "``i''" + "\\"
}

texdoc write `trump_b'
texdoc write `trump_se'

/*tex
\\
Mean Perceived Share \\
tex*/
texdoc write `constant1'
/*tex
Treatment\\
\hline
\multicolumn{7}{c}{\emph{Panel B: Instrumental Variable Regressions}}\\
\hline
            Dependent&\multicolumn{6}{l}{Amount Donated in the Dictator Game}\\
                                    &\multicolumn{1}{c}{(1)}&\multicolumn{1}{c}{(2)}&\multicolumn{1}{c}{(3)}&\multicolumn{1}{c}{(4)} & (5) & (6)\\
\hline
tex*/

texdoc write `sob_culture_50_b'
texdoc write `sob_culture_50_se'

/*tex
\\
Mean Dependent Variable at a 50\%\\
tex*/
texdoc write `constant2'
/*tex
Holding Xenophobic Views\\
\hline
\multicolumn{7}{c}{\emph{Panel C: Instrumental Variable Regressions}}\\
\hline
            Dependent&\multicolumn{6}{l}{Dummy: individual does not share anything in the dictator game}\\
                                    &\multicolumn{1}{c}{(1)}&\multicolumn{1}{c}{(2)}&\multicolumn{1}{c}{(3)}&\multicolumn{1}{c}{(4)} & (5) & (6)\\
\hline
tex*/

texdoc write `sob_culture_50c_b'
texdoc write `sob_culture_50c_se'

/*tex
\\
Mean Dependent Variable at a 50\%\\
tex*/
texdoc write `constant3'
/*tex
Holding Xenophobic Views\\
\hline
Sample & \multicolumn{2}{c}{Full Sample} & \multicolumn{2}{c}{Private Treatment} & \multicolumn{2}{c}{Public Treatment}\\
Controls & No & Yes & No & Yes & No & Yes\\
tex*/
texdoc write `obs'
/*tex
\hline
\end{tabularx}
tex*/

texdoc close



************
* Table B3 *
************

local female_avg = "Female"
local female_sd = ""
local age_avg = "Age"
local age_sd = ""
local married_avg = "Married"
local married_sd = ""
local years_edu_avg = "Years of Education"
local years_edu_sd = ""
local income_000s_avg = "Household Income"
local income_000s_sd = "\quad (000s)"
local white_avg = "White"
local white_sd = ""
local obs = "N"

local i = 1
foreach v of var `controls' {
sum `v'
local `v'_avg = "``v'_avg'" + "&" + string(round(r(mean),.001),"%9.3f")
local `v'_sd = "``v'_sd'" + "&" + "[" + string(round(r(sd),.001),"%9.3f") + "]"
if `i' == 1 {
local obs = "`obs'" + "&" + string(r(N))
}
foreach w of var clinton_private clinton_public trump_private trump_public {
sum `v' if `w' == 1
if `i' == 1 {
local obs = "`obs'" + "&" + string(r(N))
}
reg `v' clinton_private clinton_public trump_private trump_public, r nocons
local `v'_avg = "``v'_avg'" + "&" + string(round(_b[`w'],.001),"%9.3f")
local `v'_sd = "``v'_sd'" + "&" + "(" + string(round(_se[`w'],.001),"%9.3f") + ")"
}
test _b[clinton_private] = _b[clinton_public] = _b[trump_private] = _b[trump_public]
local `v'_avg = "``v'_avg'" + "&" + string(round(r(p),.001),"%9.3f")
local ++i
}

texdoc init "$ExtremeToMainstream_Replication/results/tables/tableB3.tex", replace

/*tex
\begin{tabular}{l*{6}{c}}
\\
\hline
            &\multicolumn{1}{c}{Full Sample}&\multicolumn{1}{c}{Clinton Won}&\multicolumn{1}{c}{Clinton Won}&\multicolumn{1}{c}{Trump Won}&\multicolumn{1}{c}{Trump Won}&\multicolumn{1}{c}{p-\emph{value}}\\
			&&\multicolumn{1}{c}{Private}&\multicolumn{1}{c}{Public}&\multicolumn{1}{c}{Private}&\multicolumn{1}{c}{Public}&\\
                        

            &         (1)&        (2)&        (3)&         (4)&         (5) & (6)\\
\hline
tex*/

local stata_locals female_avg female_sd age_avg age_sd married_avg married_sd years_edu_avg years_edu_sd income_000s_avg income_000s_sd white_avg white_sd obs
foreach i of local stata_locals {
texdoc local `i' = "``i''" + "\\"
}

texdoc write `female_avg'
texdoc write `female_sd'
texdoc write `age_avg'
texdoc write `age_sd'
texdoc write `married_avg'
texdoc write `married_sd'
texdoc write `years_edu_avg'
texdoc write `years_edu_sd'
texdoc write `income_000s_avg'
texdoc write `income_000s_sd'
texdoc write `white_avg'
texdoc write `white_sd'
texdoc write \hline
texdoc write `obs'
/*tex
\hline
\end{tabular}
tex*/
texdoc close



************
* Table B4 *
************

local clinton_private_b = "Clinton Won Private Treatment"
local clinton_private_se = ""
local clinton_private_p = ""
local clinton_public_b = "Clinton Won Public Treatment"
local clinton_public_se = ""
local clinton_public_p = ""
local trump_private_b = "Trump Won Private Treatment"
local trump_private_se = ""
local trump_private_p = ""
local constant = "Trump Won & \multicolumn{2}{c}"
local obs = "N"
local r2 = `"\$"' + "\mathnormal{R}^2" + "\\$"
generate treatment_ritest = 0
replace treatment_ritest = 1 if clinton_private == 1
replace treatment_ritest = 2 if clinton_public == 1
replace treatment_ritest = 3 if trump_private == 1

local j = 1
foreach outcome in donation_amount no_donation {
reg `outcome' clinton_private clinton_public trump_private, r
if `j' == 1 local constant = "`constant'" + "{" + string(round(_b[_cons],.001),"%9.3f") + "}"
if `j' == 2 local constant = "`constant'" + " & \multicolumn{2}{c}" + "{" + string(round(_b[_cons],.001),"%9.3f") + "}"
forvalues column = 1(1)2 {
if `column' == 1 reg `outcome' clinton_private clinton_public trump_private, r
if `column' == 2 reg `outcome' clinton_private clinton_public trump_private `controls', r
local obs = "`obs'" +  " & " + string(e(N))
local r2 = "`r2'" + " & " + string(round(e(r2),.001),"%9.3f")
foreach d in clinton_private clinton_public trump_private {
local `d'_b = "``d'_b'" +  " & " + string(round(_b[`d'],.001),"%9.3f")
local `d'_se = "``d'_se'" + " & " + "(" + string(round(_se[`d'],.001),"%9.3f") + ")"
}
if `column' == 1 ritest treatment_ritest (_b[i1.treatment_ritest]) (_b[i2.treatment_ritest]) (_b[i3.treatment_ritest]), reps(`n_reps') seed(1): regress `outcome' i.treatment_ritest
if `column' == 2 ritest treatment_ritest (_b[i1.treatment_ritest]) (_b[i2.treatment_ritest]) (_b[i3.treatment_ritest]), reps(`n_reps') seed(1): regress `outcome' i.treatment_ritest `controls'
matrix p = r(p)
local i = 1
foreach d in clinton_private clinton_public trump_private {
local val = p[1,`i']
if string(round(`val',.001),"%9.3f") != "0.000" local `d'_p = "``d'_p'" + " & " + "[" + string(round(`val',.001),"%9.3f") + "]"
if string(round(`val',.001),"%9.3f") == "0.000" local `d'_p = "``d'_p'" + " & " + "[" + "$<$0.001" + "]"
local ++i
}
}
local ++j
}

texdoc init "$ExtremeToMainstream_Replication/results/tables/tableB4.tex", replace

/*tex
\begin{tabular}{l*{4}{c}}
\\
\hline
            Dependent Variable&\multicolumn{2}{l}{Average donation}&\multicolumn{2}{l}{Dummy: no donation}\\
\hline
            &\multicolumn{1}{c}{(1)}&\multicolumn{1}{c}{(2)}&\multicolumn{1}{c}{(3)}&\multicolumn{1}{c}{(4)}\\
\hline
tex*/

local stata_locals clinton_private_b clinton_private_se clinton_private_p clinton_public_b clinton_public_se clinton_public_p trump_private_b trump_private_se trump_private_p constant obs r2
foreach i of local stata_locals {
texdoc local `i' = "``i''" + "\\"
}

texdoc write `clinton_private_b'
texdoc write `clinton_private_se'
texdoc write `clinton_private_p'
texdoc write `clinton_public_b'
texdoc write `clinton_public_se'
texdoc write `clinton_public_p'
texdoc write `trump_private_b'
texdoc write `trump_private_se'
texdoc write `trump_private_p'

/*tex
\\
Mean Dependent Variable\\
tex*/
texdoc write `constant'
/*tex
Public Treatment \\
\hline
Controls & No & Yes & No & Yes\\
tex*/
texdoc write `obs'
texdoc write `r2'
/*tex
\hline
\end{tabular}
tex*/

texdoc close

** EOF
