************
* SCRIPT: 5_numbers.do
* PURPOSE: creates file with in-text numbers not already available from figures and tables
************

************
* Code begins
************

* Initialize log
local datetime : di %tcCCYY.NN.DD!_HH.MM.SS `=clock("$S_DATE $S_TIME", "DMYhms")'
local logfile "$ExtremeToMainstream_Replication/results/numbers/numbers_`datetime'.txt"
log using "`logfile'", text name(log_numbers)

di "Begin date and time: $S_DATE $S_TIME"
di "Stata version: `c(stata_version)'"
di "Updated as of: `c(born_date)'"
di "Variant:       `=cond( c(MP),"MP",cond(c(SE),"SE",c(flavor)) )'"
di "Processors:    `c(processors)'"
di "OS:            `c(os)' `c(osdtl)'"
di "Machine type:  `c(machine_type)'"

********************
*** Experiment 1 ***
********************

use "$ExtremeToMainstream_Replication/processed/exp1_clean.dta", clear

* Section 3.2
* "The difference in differences between donation rates in private across 
* conditions and donation rates in public across conditions is statistically
*significant (p-value=0.008)."

reg donate trump public trump_public, r
test _b[trump_public] == 0
display "p-value=" string(round(r(p),.001),"%9.3f")


* Section 3.3
* "Empirical cumulative distributions of perceived popularity of anti-immigrant 
* sentiments for individuals in the Clinton Won treatment and in the Trump Won 
* treatment (respectively N=793 and N=794)"

ttest sob_culture, by(trump)
display "(respectively N="r(N_1) " and N="r(N_2) ")"


* Section 3.3
* "The average belief is respectively 50.1% and 42.6%"

ttest sob_culture, by(trump)
local trump = string(round(r(mu_2),.1),"%9.1f")
local clinton = string(round(r(mu_1),.1),"%9.1f")
display `trump' "% and " `clinton' "%"



********************
*** Experiment 2 ***
********************

use "$ExtremeToMainstream_Replication/processed/exp2_clean.dta", clear

* Section 4.2
* "The median amount given was $1 in all four treatments"

bysort treatment: centile donation_amount


* Section 4.3
* "The average belief is respectively 53.5% and 44.9%"

ttest sob_culture, by(trump)
local trump = string(round(r(mu_2),.1),"%9.1f")
local clinton = string(round(r(mu_1),.1),"%9.1f")
display `trump' "% and " `clinton' "%"


* Section 4.3
* E"mpirical cumulative distributions of perceived popularity of anti-immigrant 
* sentiments for individuals in the Clinton Won treatment and in the Trump Won 
* treatment (respectively N=940 and N=890)."

ttest sob_culture, by(trump)
display "(respectively N="r(N_1) " and N="r(N_2) ")"


* Section 4.3 
* "the IV estimate however is noisy, with a p-value of 0.054)"

ivregress gmm donation_amount (sob_culture = trump) if public == 1, r
test sob_culture
display "p-value of " string(round(r(p),.001),"%9.3f")


* Section 4.3 
* "dictators deciding not to transfer anything to players 2 who made a donation 
* in the public condition (p-value < 0.001)"

ivregress gmm no_donation (sob_culture = trump) if public == 1, r
test sob_culture
if string(round(r(p),.001),"%9.3f") == "0.000" local p = "< 0.001"
display "p-value `p'" 



******************************
*** Appendix Experiment 1B ***
******************************

use "$ExtremeToMainstream_Replication/processed/app_exp1b_clean.dta", clear

* Section D.1
* "we recruited participants (N = 458)"

count if inlist(wave,"Wave 1","Wave 1 pilot")
display "N = " r(N) 


* Section D.1
* "more than 90% of participants (N=428) would get assigned"
count if inlist(wave,"Wave 1","Wave 1 pilot") & missing(donation_anti) == 0
display "N=" r(N) 

* Section D.1
* "We analyze the behavior of subjects who were part of our sample before the 
*election (N = 168; 166 of them assigned to the anti-immigration organization)"

count if inlist(wave2_surveyed_before,1)
local a = r(N)
count if inlist(wave2_surveyed_before,1) & missing(donation_anti) == 0
display "N = " `a' "; "r(N) 


* Section D.2
* "Moreover, we find no significant difference in private donation rates between 
* the information and control conditions (p-value=0.281)"

reg donate control_private control_public info_private info_public wave2_private wave2_public if (wave == "Wave 1 pilot" | wave == "Wave 1" | (wave == "Wave 2" & wave2_surveyed_before == 1)), nocons r
test _b[control_private] = _b[info_private]
display "p-value=" string(round(r(p),.001),"%9.3f")


* Section D.2
* "the difference in differences between donation rates in private across
* conditions and donation rates in public across conditions (p-value=0.050)."

reg donate control_private control_public info_private info_public wave2_private wave2_public if (wave == "Wave 1 pilot" | wave == "Wave 1" | (wave == "Wave 2" & wave2_surveyed_before == 1)), nocons r
test _b[control_private] - _b[info_private] = _b[control_public] - _b[info_public]
display "p-value=" string(round(r(p),.001),"%9.3f")


* Section D.2
* "(54% before the election and 49% after the election, p-value=0.436)"

reg donate control_private control_public info_private info_public wave2_private wave2_public if (wave == "Wave 1 pilot" | wave == "Wave 1" | (wave == "Wave 2" & wave2_surveyed_before == 1)), nocons r
test _b[control_private] = _b[wave2_private]
display "p-value=" string(round(r(p),.001),"%9.3f")


* Section D.2
* "The difference in differences between donation rates in private before and 
* after the election and donation rates in public before and after the election 
* in the control condition is also statistically significant (p-value=0.062)."

reg donate control_private control_public info_private info_public wave2_private wave2_public if (wave == "Wave 1 pilot" | wave == "Wave 1" | (wave == "Wave 2" & wave2_surveyed_before == 1)), nocons r
test _b[control_private] - _b[wave2_private] = _b[control_public] - _b[wave2_public]
display "p-value=" string(round(r(p),.001),"%9.3f")


* Figure D1 Notes
* "(full sample, respectively N=112 and N=111), the two central bars display 
* those in the information group before the election (full sample, respectively 
* N=102 and N=103), and the last two bars display those in the control group 
* after the election (for individuals already surveyed before the election, 
* respectively N=82 and N=84)"

count if control_private == 1 & missing(donation_anti) == 0 & (wave == "Wave 1 pilot" | wave == "Wave 1" | (wave == "Wave 2" & wave2_surveyed_before == 1))
local a = r(N)
count if control_public == 1 & missing(donation_anti) == 0 & (wave == "Wave 1 pilot" | wave == "Wave 1" | (wave == "Wave 2" & wave2_surveyed_before == 1))
local b = r(N)
count if info_private == 1 & missing(donation_anti) == 0 & (wave == "Wave 1 pilot" | wave == "Wave 1" | (wave == "Wave 2" & wave2_surveyed_before == 1))
local c = r(N)
count if info_public == 1 & missing(donation_anti) == 0 & (wave == "Wave 1 pilot" | wave == "Wave 1" | (wave == "Wave 2" & wave2_surveyed_before == 1))
local d = r(N)
count if wave2_private == 1 & missing(donation_anti) == 0 & (wave == "Wave 1 pilot" | wave == "Wave 1" | (wave == "Wave 2" & wave2_surveyed_before == 1))
local e = r(N)
count if wave2_public == 1 & missing(donation_anti) == 0 & (wave == "Wave 1 pilot" | wave == "Wave 1" | (wave == "Wave 2" & wave2_surveyed_before == 1))
display "N=`a' and N=`b'... N=`c' and N=`d' ... N=`e'" " and N="r(N)



******************************
*** Appendix Experiment 2B ***
******************************

use "$ExtremeToMainstream_Replication/processed/app_exp2b_clean.dta", clear

* Section E.1
* "subjects who reported to be against the introduction of this law (N = 396)"

count if inlist(minarets,"No, I think the building of minarets should be allowed in [state].") == 1 & inlist(wave,"Wave 1") == 1 & referendum == 0 
display "N = "r(N)


* Section E.1
* "Subjects who instead supported the law (N = 152)"

count if inlist(minarets,"Yes, I think the building of minarets should be prohibited in [state].") == 1 & inlist(wave,"Wave 1") == 1 & referendum == 0 
display "N = "r(N)


* Section E.1
* "subjects who reported to be against the introduction of the ban (N = 427)"

count if inlist(minarets,"No, I think the building of minarets should be allowed in [state].") == 1 & inlist(wave,"Wave 2") == 1 & referendum_anonymous == 0 
display "N = "r(N)


* Section E.1
* "Subjects who instead supported the law (N = 138)"

count if inlist(minarets,"Yes, I think the building of minarets should be prohibited in [state].") == 1 & inlist(wave,"Wave 2") == 1 & referendum_anonymous == 0 
display "N = "r(N)


* Section E.1
* "Our design also included a fourth group (N=136 in wave 1, and N=139 in wave 2)"

count if inlist(minarets,"No, I think the building of minarets should be allowed in [state].") == 1 & inlist(wave,"Wave 1") == 1 & referendum == 1 
local a = r(N)
count if inlist(minarets,"No, I think the building of minarets should be allowed in [state].") == 1 & inlist(wave,"Wave 2") == 1 & referendum_anonymous == 1 
display "(N=`a' in wave 1, and N=" r(N) " in wave 2)"


* Section E.1.1
* "(respectively 20% and 25%, with a p-value for the test of equality of 0.301)"

ttest sob_50 if ((control == 1 | anti_minarets_anonymous == 1) & wave == "Wave 2"), by(control)
display "(respectively " string(round(r(mu_2)*100,1)) "% and " string(round(r(mu_1)*100,1)) "%, with a p-value for the test of equality of " string(round(r(p),.001),"%9.3f") ")"


* Section E.1.1
* "increases to 63% in the anonymous anti-minarets public supportgroup (p-values
* of the test of equality are less than 0.001 for either groups)"

ttest sob_50 if ((support_anonymous == 1 | anti_minarets_anonymous == 1) & wave == "Wave 2"), by(support_anonymous)
if string(round(r(p),.001),"%9.3f") == "0.000" local a = "0.001"
display "increases to " string(round(r(mu_2)*100,1)) "% in the anonymous anti-minarets public supportgroup (p-values of the test of equality are less than " "`a'"


* Section E.1.1
* "The median belief about the share of the Swiss population supporting the ban 
* is 30% in both control and anonymous anti-minarets groups, and 55% in the 
* anonymous anti-minarets public support group."

centile sob if control == 1 & wave == "Wave 2"
centile sob if anti_minarets_anonymous == 1 & wave == "Wave 2"
local a = string(r(c_1))
centile sob if support_anonymous == 1 & wave == "Wave 2"
display `a' "% in both control and anonymous anti-minarets groups, and " r(c_1) "%"


* Section E.1.1
* "In the first wave, 17% of control group participants believe a majority of 
* Swiss people support the ban, compared to 20% in the second wave. The median
* belief is 30% for the control groups in both waves."

mean sob_50 if control == 1 & wave == "Wave 1"
matrix A = e(b)
centile sob if control == 1 & wave == "Wave 1"
display "In the first wave, " round(A[1,1]*100,1) "% of control group participants ... median belief is " r(c_1) "%"


* Section E.1.1
* "(88% in the control group, 77% in the anti-minarets group, and 74% in the 
* anti-minarets public support group)."

ttest believe_legal if ((control == 1 | anti_minarets_anonymous == 1) & wave == "Wave 2"), by(control)
local a = round(r(mu_2)*100,1)
ttest believe_legal if ((support_anonymous == 1 | anti_minarets_anonymous == 1) & wave == "Wave 2"), by(support_anonymous)
display "`a'% in the control group, " round(r(mu_1)*100,1) "% in the anti-minarets group, and " round(r(mu_2)*100,1) "%"


* Section E.1.1
* "(the p-values for the test of equality are 0.013 against the anonymous 
* anti-minarets group and 0.002 against the anonymous anti-minarets public 
* support group), there is no statistical difference between the two treatment
* groups (the p-value for the test of equality is 0.500)."

ttest believe_legal if ((control == 1 | anti_minarets_anonymous == 1) & wave == "Wave 2"), by(control)
local a = string(round(r(p),.001),"%9.3f")
ttest believe_legal if ((control == 1 | support_anonymous == 1) & wave == "Wave 2"), by(control)
local b = string(round(r(p),.001),"%9.3f")
ttest believe_legal if ((support_anonymous == 1 | anti_minarets_anonymous == 1) & wave == "Wave 2"), by(support_anonymous)
display "`a' against the anonymous anti-minarets group and `b' against ... equality is " string(round(r(p),.001),"%9.3f")


* Figure E1 Notes
* "(N = 279, pooling 142 observations from the first version of Experiment 2 
* and 137 observations from the second anonymous version of Experiment 2), the 
* anti-minarets group (N=123), and the anti-minarets public support group 
* (N=131), the anonymous anti-minarets group (N=149), and the anonymous anti-
* minarets public support group (N=141)"

count if control == 1
local a = string(r(N))
count if control == 1 & wave == "Wave 1"
local b = string(r(N))
count if control == 1 & wave == "Wave 2"
local c = string(r(N))
count if anti_minarets == 1
local d = string(r(N))
count if support == 1
local e = string(r(N))
count if anti_minarets_anonymous == 1
local f = string(r(N))
count if support_anonymous == 1
display "N = `a', pooling `b' ... and `c' observations ... (N=`d') ... (N=`e') ... (N=`f') ... (N=" r(N)



*****************************
*** Appendix Experiment 3 ***
*****************************

use "$ExtremeToMainstream_Replication/processed/app_exp3_clean.dta", clear

* Section F.1
* "we recruited participants (N = 574)"

display "(N = " _N ")"


use "$ExtremeToMainstream_Replication/processed/app_exp3_auxiliarysurvey_clean.dta", clear

* Section F.1
* "We used information from a previous anonymous survey we conducted on MTurk '
* (N = 96) in which 42% of the respondents"

count if public_office == "Yes"
display "(N = " _N ") in which " round(100*r(N)/_N) "%"


use "$ExtremeToMainstream_Replication/processed/app_exp3_clean.dta", clear

* Section F.1
* "participants (N=573) would get assigned"

count if donation_anti != ""
display "N="r(N)


* Section F.2
* "In the control group, the average guess was that 45% of respondents"

mean(sob) if inlist(treatment,"Control Private", "Control Public") == 1
matrix A=e(b)
display round(A[1,1],1) "%"


* Section F.2
* "The average went up to 48% in the unconstitutionality information condition 
* (p-value=0.183 against the control group)"

ttest sob if inlist(treatment,"Control Private", "Control Public","Unconstitutionality Information Private","Unconstitutionality Information Public") == 1, by(control)
display round(r(mu_1),1) "% ... p-value=" string(round(r(p),.001),"%9.3f")


* Section F.2
* "and to 52% in popular support information condition (p-value=0.004 when 
* compared to the control group)"

ttest sob if inlist(treatment,"Control Private", "Control Public","Public Support Information Private","Public Support Information Public") == 1, by(control)
display round(r(mu_1),1) "% ... p-value=" string(round(r(p),.001),"%9.3f")


* Figure F1 Notes
* "individuals in the private and public conditions in the control group 
* (respectively N=91 and N=96), the two central bars display those in the 
* public support information group (respectively N=98 and N=95), and the last 
* two bars display those in the unconstitutionality information group 
* (respectively N=101 and N=92)"

count if control_private == 1 & missing(donation_anti)==0
local a = string(r(N))
count if control_public == 1 & missing(donation_anti)==0
local b = string(r(N))
count if support_private == 1 & missing(donation_anti)==0
local c = string(r(N))
count if support_public == 1 & missing(donation_anti)==0
local d = string(r(N))
count if const_private == 1 & missing(donation_anti)==0
local e = string(r(N))
count if const_public == 1 & missing(donation_anti)==0
display "N=`a' and N=`b' ... N=`c' and N=`d' ... N=`e' and N=" r(N)


* End log
log close log_numbers

** EOF
